@@ -1,7 +1,7 @@
 package Pod::Weaver::Plugin::Bencher::Scenario;
 
-our $DATE = '2016-01-06'; # DATE
-our $VERSION = '0.04'; # VERSION
+our $DATE = '2016-01-13'; # DATE
+our $VERSION = '0.05'; # VERSION
 
 use 5.010001;
 use Moose;
@@ -238,7 +238,9 @@ sub weave_section {
 }
 
 1;
-# ABSTRACT: Put various information from scenario into POD
+# ABSTRACT: Plugin to use when building Bencher::Scenario::* distribution
+
+
 
 __END__
 
@@ -248,11 +250,11 @@ __END__
 
 =head1 NAME
 
-Pod::Weaver::Plugin::Bencher::Scenario - Put various information from scenario into POD
+Pod::Weaver::Plugin::Bencher::Scenario - Plugin to use when building Bencher::Scenario::* distribution
 
 =head1 VERSION
 
-This document describes version 0.04 of Pod::Weaver::Plugin::Bencher::Scenario (from Perl distribution Pod-Weaver-Plugin-Bencher-Scenario), released on 2016-01-06.
+This document describes version 0.05 of Pod::Weaver::Plugin::Bencher::Scenario (from Perl distribution Pod-Weaver-Plugin-Bencher-Scenario), released on 2016-01-13.
 
 =head1 SYNOPSIS
 
@@ -262,10 +264,32 @@ In your C<weaver.ini>:
 
 =head1 DESCRIPTION
 
-This plugin is to be used when building C<Bencher::Scenario::*> modules.
+This plugin is to be used when building C<Bencher::Scenario::*> distribution.
+Currently it does the following:
+
+=over
+
+=item * Add a Synopsis section (if doesn't already exist) containing a few examples on how to use the scenario
+
+=item * Add a description about Bencher in the Description section
+
+=item * Add a Benchmark Participants section containing list of participants from the scenario
+
+=item * Add a Sample Benchmark Results containing result from a bencher run
+
+Both normal benchmark and a separate module startup benchmark (if eligible) are
+run and shown.
+
+=item * Add a Benchmarked Modules section containing list of benchmarked modules (if any) from the scenario and their versions
+
+=back
 
 =for Pod::Coverage ^(weave_section)$
 
+=head1 SEE ALSO
+
+L<Dist::Zilla::Plugin::Bencher::Scenario>
+
 =head1 HOMEPAGE
 
 Please visit the project's homepage at L<https://metacpan.org/release/Pod-Weaver-Plugin-Bencher-Scenario>.
@@ -294,3 +318,4 @@ This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
+
